.. AntiSplodge documentation master file, created by
   sphinx-quickstart on Mon May 24 11:33:28 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to AntiSplodge's documentation!
=======================================

The main functions are stored in the antisplodge file.

.. toctree::
   :maxdepth: 4
   :caption: Contents:

   antisplodge


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
